Heatshields: Contact Us
Description: We sell windshield sun shades for cars, trucks, and vans. Heatshield protects against heat damage, and keeps the inside of parked cars cooler.

Internet Explorer users: There have been issues during checkout. Please use an alternative browser.

- catalog
- cart (0)
- FAQs
- about us
- contact us
- feedback

# Contact Us

Questions? Comments? Trouble with the site? Drop us a line!

Listed below are all the ways in which you can contact us.

**Please note that we will be closed the week between Christmas and New Year. We will be in the office through Friday, December 20 and returning Thursday, January 2, 2014.

by phone:
(408)738-3959
or toll-free (U.S. & Canada Only):
(800)777-6405

by email:
info@heatshieldstore.com

by online form:

Full Name
E-mail Address
Your Message

by street address:
Canvas Works
18850 Adams Ct
Morgan Hill, CA 95037
view map